@@ -3,6 +3,7 @@ from .update_cost_center_input_params import UpdateCostCenterInputParams
 from travelperk_python_api_types.cost_centers.cost_centers.cost_center_detail import (
     CostCenterDetail,
 )
+from travelperk_http_python.dataclass_wrapper.dataclass_wrapper import DataclassWrapper
 
 if TYPE_CHECKING:
     from api.travelperk import TravelPerk
@@ -15,10 +16,11 @@ class UpdateCostCenterRequest:
         self.travelperk = travelperk
 
     def save(self) -> CostCenterDetail:
-        return CostCenterDetail(
-            **self.travelperk.patch(
+        return DataclassWrapper.wrap(
+            CostCenterDetail,
+            self.travelperk.patch(
                 "/".join(["cost_centers", str(self.id)]), self.params.to_dict()
-            )
+            ),
         )
 
     def set_name(self, name: str) -> "UpdateCostCenterRequest":
